@@ -7,6 +7,7 @@
 #' @param ... passed to predict.crr
 #'
 #' @examples
+##' library(prodlim)
 #' library(survival)
 #' set.seed(10)
 #' d <- sampleData(101, outcome = "competing.risk")
@@ -24,8 +25,13 @@ predict.FGR <- function(object,newdata,times,...){
     ## EHF <- prodlim::model.design(rhs,
                                  ## newdata,
                                  ## dropIntercept=TRUE,
-                                 ## specialsDesign=TRUE)
-    EHF <- prodlim::EventHistory.frame(formula(object$terms),
+    ## specialsDesign=TRUE)
+    ## need "response" to make EventHistory.frame work
+    ## but Score removes response for prediction
+    newdata$dummy.time=1
+    newdata$dummy.event=1
+    dummy.formula=stats::update.formula(rhs,"Hist(dummy.time,dummy.event)~.")
+    EHF <- prodlim::EventHistory.frame(dummy.formula,
                                        data=newdata,
                                        specials=c("cov1","cov2"),
                                        stripSpecials=c("cov1","cov2"),
@@ -42,6 +48,7 @@ predict.FGR <- function(object,newdata,times,...){
     args <- list(object=object$crrFit,cov1=cov1,cov2=cov2,...)
     args <- args[!sapply(args,is.null)]
     ## warning("uuu")
+    ## print(colnames(args$cov1))
     pred <- do.call(cmprsk::predict.crr,args)
     ## warning("bbb")
     out <- pred[,-1,drop=FALSE]
