@@ -5,7 +5,7 @@
 ##' @return list with two elements: ctree and call
 ##' @seealso Cforest
 ##' @examples
-##' if (requireNamespace("party",quietly=TRUE)){
+##' if (require("party",quietly=TRUE)){
 ##' library(prodlim)
 ##' library(party)
 ##' library(survival)
@@ -16,7 +16,6 @@
 ##' predictRisk(f,newdata=nd,times=c(3,8))
 ##' }
 ##' 
-##' 
 ##' @author Thomas A. Gerds <tag@@biostat.ku.dk>
 ##' @export 
 Ctree <- function(...){
@@ -31,6 +30,7 @@ predictRisk.Ctree <- function (object, newdata, times, ...) {
     requireNamespace("party")
     N <- NROW(newdata)
     NT <- length(times)
+    data.table::setDF(newdata)
     survObj <- party::treeresponse(object$ctree, newdata=newdata)
     p <- do.call("rbind", lapply(survObj,function(x){
         predictRisk(x, newdata=newdata[1,,drop=FALSE], times=times)
