@@ -3,7 +3,7 @@
 ## Author: Thomas Alexander Gerds
 ## Created: Nov  4 2019 (09:07) 
 ## Version: 
-## Last-Updated: Sep  6 2023 (09:53) 
+## Last-Updated: Mar 26 2025 (07:05) 
 ##           By: Thomas Alexander Gerds
 ##     Update #: 21
 #----------------------------------------------------------------------
@@ -29,13 +29,13 @@ print.IPA <- function(x,digits=2,...){
     if (missing(digits)){
         digits <- 1 
     }
-    X <- data.table::copy(x)
+    X <- copy(x)
     data.table::setDT(X)
     fmt <- paste0("%1.",digits[[1]],"f")
     X[,Brier:=sprintf(fmt=fmt,100*Brier)]
     X[,IPA:=sprintf(fmt=fmt,100*IPA)]
     if (match("IPA.drop",colnames(X),nomatch=0)) X[,IPA.drop:=sprintf(fmt=fmt,100*IPA.drop)]
-    print(X,...)
+    print(X[],...)
     message("\nNOTE: Values are multiplied by 100 and given in %.")
     message("NOTE: The higher IPA the better.")
     message("NOTE: IPA.drop = IPA(Full model) - IPA. The higher the drop\nthe more important is the variable for the full model.")
