@@ -3,9 +3,9 @@
 ## Author: Thomas Alexander Gerds
 ## Created: Dec 26 2019 (08:58) 
 ## Version: 
-## Last-Updated: Jul  2 2024 (11:50) 
-##           By: Thomas Alexander Gerds
-##     Update #: 91
+## Last-Updated: Aug  18 2025 
+##           By: Asbjørn Risom
+##     Update #: 92
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -38,7 +38,7 @@ summary.Score <- function(object,
                           pvalue.digits=4,
                           ...){
     ## score
-    out=AUC=model=lower=upper=Brier=Model=x=reference=delta.AUC=p=delta.Brier=Reference=NULL
+    out=AUC=model=lower=upper=Brier=Model=x=reference=delta.AUC=p=delta.Brier=Reference=lower.IPA=upper.IPA=NULL
     what <- sapply(tolower(what),function(w){match.arg(w,c("score","contrasts"))})
     # check models 
     fitted.models <- names(object$models)
@@ -62,13 +62,18 @@ summary.Score <- function(object,
                                                                    "AUC (%)"=Publish::pubformat(x=100*AUC,digits=digits))]
             }
             if ("upper"%in%names(object$Brier$score)){
-                if ("IPA"%in% names(object$Brier$score))
-                    tab.Brier <- object$Brier$score[(model %in% models),data.table::data.table(Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::formatCI(x=100*Brier,lower=100*lower,upper=100*upper,show.x=1,digits=digits),IPA=sprintf(paste0("%1.",digits,"f"),100*IPA))]
+                if (!is.null(object$IPA)){
+                  brier.merge <- merge(object$Brier$score,object$IPA$score, by = "model", suffixes = c("",".IPA"))
+                  tab.Brier <- brier.merge[(model %in% models),data.table::data.table(Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::formatCI(x=100*Brier,lower=100*lower,upper=100*upper,show.x=1,digits=digits),
+                                                                                      "IPA (%)"=Publish::formatCI(x=100*IPA,lower=100*lower.IPA,upper=100*upper.IPA,show.x=1,digits=digits))]
+                }
                 else
                     tab.Brier <- object$Brier$score[(model %in% models),data.table::data.table(Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::formatCI(x=100*Brier,lower=100*lower,upper=100*upper,show.x=1,digits=digits))]
             }else{
-                if ("IPA"%in% names(object$Brier$score))
-                    tab.Brier <- object$Brier$score[(model %in% models),data.table::data.table(Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::pubformat(x=100*Brier,digits=digits),IPA=sprintf(paste0("%1.",digits,"f"),100*IPA))]
+                if (!is.null(object$IPA)){
+                  brier.merge <- merge(object$Brier$score,object$IPA$score, by = "model", suffixes = c("",".IPA"))
+                  tab.Brier <- brier.merge[(model %in% models),data.table::data.table(Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::pubformat(x=100*Brier,digits=digits),IPA=sprintf(paste0("%1.",digits,"f"),100*IPA))]
+                }
                 else
                     tab.Brier <- object$Brier$score[(model %in% models),data.table::data.table(Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::pubformat(x=100*Brier,digits=digits))]
             }
@@ -160,13 +165,17 @@ summary.Score <- function(object,
             }else{tab.AUC <- NULL}
             if (length(object$Brier$score)>0){
                 if ("upper"%in%names(object$Brier$score)){
-                    if ("IPA"%in% names(object$Brier$score))
-                        tab.Brier <- object$Brier$score[(times%in%ttt)&(model%in%models),data.table::data.table(times=times,Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::formatCI(x=100*Brier,lower=100*lower,upper=100*upper,show.x=1,digits=digits),IPA=sprintf(paste0("%1.",digits,"f"),100*IPA))]
+                    if (!is.null(object$IPA)){
+                        brier.merge <- merge(object$Brier$score,object$IPA$score, by = c("times","model"), suffixes = c("",".IPA"))
+                        tab.Brier <- brier.merge[(times%in%ttt)&(model%in%models),data.table::data.table(times=times,Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::formatCI(x=100*Brier,lower=100*lower,upper=100*upper,show.x=1,digits=digits),"IPA (%)"=Publish::formatCI(x=100*IPA,lower=100*lower.IPA,upper=100*upper.IPA,show.x=1,digits=digits))]
+                        }
                     else
                         tab.Brier <- object$Brier$score[(times%in%ttt)&(model%in%models),data.table::data.table(times=times,Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::formatCI(x=100*Brier,lower=100*lower,upper=100*upper,show.x=1,digits=digits))]
                 }else{
-                    if ("IPA"%in% names(object$Brier$score))
-                        tab.Brier <- object$Brier$score[(times%in%ttt)&(model%in%models),data.table::data.table(times=times,Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::pubformat(x=100*Brier,digits=digits),IPA=sprintf(paste0("%1.",digits,"f"),100*IPA))]
+                    if (!is.null(object$IPA)){
+                        brier.merge <- merge(object$Brier$score,object$IPA$score, by = c("times","model"), suffixes = c("",".IPA"))
+                        tab.Brier <- brier.merge[(times%in%ttt)&(model%in%models),data.table::data.table(times=times,Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::pubformat(x=100*Brier,digits=digits),"IPA (%)"=sprintf(paste0("%1.",digits,"f"),100*IPA))]
+                    }
                     else
                         tab.Brier <- object$Brier$score[(times%in%ttt)&(model%in%models),data.table::data.table(times=times,Model=factor(model,levels=fitted.models)[,drop=TRUE],"Brier (%)"=Publish::pubformat(x=100*Brier,digits=digits))]
                 }
