@@ -1,5 +1,6 @@
 // [[Rcpp::depends(RcppArmadillo)]]
-#include "arma-wrap.h"
+#include <RcppArmadillo.h>
+#include "IC-Nelson-Aalen-cens-time.h"
 
 using namespace Rcpp;
 using namespace arma;
@@ -8,17 +9,12 @@ using namespace arma;
 // see https://github.com/eestet75/riskRegressionStudy/blob/master/PicsForImplementation/BrierTrainTest.png
 // Should be used with loob estimates and generally 
 // [[Rcpp::export(rng=false)]]
-NumericVector getInfluenceFunctionBrierKMCensoringUseSquared(double tau,
+NumericVector getInfluenceFunctionBrierKMCensoringTerm(double tau,
                                                              NumericVector time,
                                                              NumericVector residuals,
                                                              NumericVector status) {
-  checkNAs(tau, GET_VARIABLE_NAME(tau));
-  checkNAs(time, GET_VARIABLE_NAME(time));
-  checkNAs(residuals, GET_VARIABLE_NAME(residuals));
-  checkNAs(status, GET_VARIABLE_NAME(status));
-
   int n = time.size();
-  NumericVector ic(n);
+  NumericVector ictermvec(n);
   arma::uvec sindex(n,fill::zeros);
   arma::vec utime=unique(time);
   int nu=utime.size();
@@ -34,7 +30,7 @@ NumericVector getInfluenceFunctionBrierKMCensoringUseSquared(double tau,
   double icpart2 = 0;
   double icpart = 0;
   for (int i = 0; i < n; i++){
-    if (status[i] == 1 && time[i] <= tau){
+    if (status[i] != 0 && time[i] <= tau){
       icpart2 += residuals[i];
     }
     else if (time[i] > tau){
@@ -42,11 +38,10 @@ NumericVector getInfluenceFunctionBrierKMCensoringUseSquared(double tau,
     }
   }
   icpart = icpart / ( (double) n);
-  double brier = mean(residuals);
   int tieIter = 0;
   // can do while loops together
   while ((tieIter < n) && (time[tieIter] == time[0])) {
-    if ((time[tieIter] <= tau) && (status[tieIter]==1)){
+    if (time[tieIter] <= tau && status[tieIter]!=0){
       icpart2 -= residuals[tieIter];
     }
     tieIter++;
@@ -75,7 +70,7 @@ NumericVector getInfluenceFunctionBrierKMCensoringUseSquared(double tau,
     if (upperTie == i){
       int tieIter = i+1;
       while ((tieIter < n) && (time[tieIter] == time[i+1])) {
-        if ((time[tieIter] <= tau) && (status[tieIter]==1)){
+        if (time[tieIter] <= tau && status[tieIter]!=0){
           icpart1 -= residuals[tieIter]*MC_term2[sindex[i]];
           icpart2 -= residuals[tieIter];
         }
@@ -83,7 +78,7 @@ NumericVector getInfluenceFunctionBrierKMCensoringUseSquared(double tau,
       }
       upperTie = tieIter-1;
     }
-    ic[i] = residuals[i] - brier + icterm+icterm2;
+    ictermvec[i]=icterm+icterm2;
   }
-  return ic;
+  return ictermvec;
 }
